.. pysumstats documentation master file, created by
   sphinx-quickstart on Mon May 11 10:08:27 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

########################
pysumstats documentation
########################

Welcome to pysumstats's documentation!

Contents
========
.. include:: contents.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
